@@ -19,14 +19,23 @@ class Person(Base):
     )
 
     prefix_name = Column(String)
+
     first_name = Column(String)
+
     middle_name = Column(String)
+
     last_name = Column(String)
+
     suffix_name = Column(String)
+
     full_legal_name = Column(String)
+
     nickname = Column(String)
+
     birth_date = Column(Date)
+
     birth_place_name = Column(String)
+
     gender_code = Column(String)
 
     person_profession = relationship(
@@ -59,6 +68,12 @@ class Person(Base):
         back_populates='person'
     )
 
+    party_assessment = relationship(
+        'PartyAssessment',
+        primaryjoin='Person.person_id == PartyAssessment.person_id',
+        back_populates='party_assessment'
+    )
+
     def __repr__(self):
         return "<Person(" \
                "prefix_name='%s', " \
@@ -507,6 +522,24 @@ class PartyRole(Base):
         back_populates='party_role'
     )
 
+    arbitration_party_role = relationship(
+        'ArbitrationPartyRole',
+        primaryjoin='PartyRole.party_role_code == ArbitrationPartyRole.party_role_code',
+        back_populates='party_role'
+    )
+
+    litigation_party_role = relationship(
+        'LitigationPartyRole',
+        primaryjoin='PartyRoleCode.party_role_code == LitigationPartyRole.party_role_code',
+        back_populates='party_role'
+    )
+
+    assessment_party_role = relationship(
+        'AssessmentPartyRole',
+        primaryjoin='PartyRole.party_role_code == AssessmentPartyRole.party_role_code',
+        back_populates='party_role'
+    )
+
     def __repr__(self):
         return "<PartyRole(" \
                "party_role_name='%s', " \
@@ -599,6 +632,30 @@ class Party(Base):
         back_populates='party'
     )
 
+    arbitration_party_role = relationship(
+        'ArbitrationPartyRole',
+        primaryjoin='Party.party_id == ArbitrationPartyRole.party_id',
+        back_populates='party'
+    )
+
+    litigation_party_role = relationship(
+        'LitigationPartyRole',
+        primaryjoin='Party.party_id == LitigationPartyRole.party_id',
+        back_populates='party'
+    )
+
+    assessment_party_role = relationship(
+        'AssessmentPartyRole',
+        primaryjoin='Party.party_id == AssessmentPartyRole.party_id',
+        back_populates='party'
+    )
+
+    party_assessment = relationship(
+        'PartyAssessment',
+        primaryjoin='Party.party_id == PartyAssessment.party_id',
+        back_populates='party'
+    )
+
     def __repr__(self):
         return "<Party(" \
                "party_name='%s', " \
@@ -1038,6 +1095,12 @@ class GeographicLocation(Base):
         back_populates='geographic_location'
     )
 
+    occurrence = relationship(
+        'Occurrence',
+        primaryjoin='GeographicLocation.geographic_location_id == Occurrence.geographic_location_id',
+        back_populates='geographic_location'
+    )
+
     def __repr__(self):
         return "<GeographicLocation(" \
                "geographic_location_type_code='%s', " \
@@ -1105,6 +1168,12 @@ class InsurableObject(Base):
         back_populates='insurable_object'
     )
 
+    object_assessment = relationship(
+        'ObjectAssessment',
+        primaryjoin='InsurableObject.insurable_object_id == ObjectAssessment.insurable_object_id',
+        back_populates='insurable_object'
+    )
+
     def __repr__(self):
         return "<InsurableObject(" \
                "insurable_object_type_code='%s', " \
@@ -1123,21 +1192,39 @@ class Claim(Base):
         primary_key=True
     )
 
-    occurrence_id = Column(Integer)
-    catastrophe_id = Column(Integer)
+    occurrence_id = Column(
+        Integer,
+        ForeignKey('occurrence.occurrence_id')
+    )
+
+    catastrophe_id = Column(
+        Integer,
+        ForeignKey('catastrophe.catastrophe_id')
+    )
+
     insurable_object_id = Column(
         Integer,
         ForeignKey('insurable_object.insurable_object_id')
     )
+
     company_claim_number = Column(Integer)
+
     company_subclaim_number = Column(Integer)
+
     claim_description = Column(String)
+
     claim_open_date = Column(Date)
+
     claim_close_date = Column(Date)
+
     claim_reopen_date = Column(Date)
+
     claim_status_code = Column(String)
+
     claim_reported_date = Column(Date)
+
     claims_made_date = Column(Date)
+
     entry_in_to_claims_made_program_date = Column(Date)
 
     insurable_object = relationship(
@@ -1146,6 +1233,66 @@ class Claim(Base):
         back_populates='claim'
     )
 
+    occurrence = relationship(
+        'Occurrence',
+        primaryjoin='Claim.occurrence_id == Occurrence.occurrence_id',
+        back_populates='claim'
+    )
+
+    catastrophe = relationship(
+        'Catastrophe',
+        primaryjoin='Claim.catastrophe_id == Catastrophe.catastrophe_id',
+        back_populates='claim'
+    )
+
+    claim_coverage = relationship(
+        'ClaimCoverage',
+        primaryjoin='Claim.claim_id == ClaimCoverage.claim_id',
+        back_populates='claim'
+    )
+
+    claim_amount = relationship(
+        'ClaimAmount',
+        primaryjoin='Claim.claim_id == ClaimAmount.claim_id',
+        back_populates='claim'
+    )
+
+    claim_folder = relationship(
+        'ClaimFolder',
+        primaryjoin='Claim.claim_id == ClaimFolder.claim_id',
+        back_populates='claim'
+    )
+
+    arbitration_party_role = relationship(
+        'ArbitrationPartyRole',
+        primaryjoin='Claim.claim_id == ArbitrationPartyRole.claim_id',
+        back_populates='claim'
+    )
+
+    claim_litigation = relationship(
+        'ClaimLitigation',
+        primaryjoin='Claim.claim_id == ClaimLitigation.claim_id',
+        back_populates='claim'
+    )
+
+    claim_arbitration = relationship(
+        'ClaimArbitration',
+        primaryjoin='Claim.claim_id == ClaimArbitration.claim_id',
+        back_populates='claim'
+    )
+
+    litigation_party_role = relationship(
+        'LitigationPartyRole',
+        primaryjoin='Claim.claim_id == LitigationPartyRole.claim_id',
+        back_populates='claim'
+    )
+
+    claim_assessment = relationship(
+        'ClaimAssessment',
+        primaryjoin='Claim.claim_id == ClaimAssessment.claim_id',
+        back_populates='claim'
+    )
+
     def __repr__(self):
         return "<Claim(" \
                "occurrence_id='%s', " \
@@ -1433,6 +1580,12 @@ class Agreement(Base):
         back_populates='agreement'
     )
 
+    agreement_assessment = relationship(
+        'AgreementAssessment',
+        primaryjoin='Agreement.agreement_id == AgreementAssessment.agreement_id',
+        back_populates='agreement'
+    )
+
     def __repr__(self):
         return "<Agreement(" \
                "agreement_type_code='%s', " \
